import setuptools

setuptools.setup(
    name="PEViT", #
    version='0.0.7',
    author='xuehaihe',
    author_email='xuehaihe2008@gmail.com',
    url='https://github.com/jkooy/KroneckerAdapter',
    description="Parameter-efficient Finetuning for ViT",
    python_requires='>=3.6'
)